@@ -13,7 +13,6 @@ use Cwd qw(realpath);
 require Exporter;
 
 # cpan modules
-use YAML::Dumper;
 use Term::ANSIColor;
 
 # Larry's STD.pm
@@ -23,8 +22,14 @@ use STD;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw();
 our @EXPORT = qw();
-our $VERSION = '0.01_01';
+our $VERSION = '0.02';
 
+# filename constants
+use constant FILE_CSS    => "p6_style.css";
+use constant FILE_ANSI   => "p6_style.ansi";
+use constant FILE_JS     => "p6_style.js";
+use constant FILE_JQUERY => "jquery-1.2.6.pack.js";
+ 
 # These are needed for redspans
 $::ACTIONS = 'Actions';
 
@@ -45,8 +50,9 @@ my $SHARED = realpath(File::Spec->join(
 sub new($%) {
     my ($class, %options) = @ARG;
     $options{rule} = $options{rule} // 'comp_unit';
-    $options{clean_html} = $options{clean_html} // 1;
-    $options{file} = $options{file} // qq{option 'file' is not set'};
+    $options{inline_resources} = $options{inline_resources} // 0;
+    $options{resource_url} = $options{resource_url} // qq{};
+    $options{page_title} = $options{page_title} // qq{};
     $options{utf8_decode} = $options{utf8_decode} // 1;
 
     #is 'text' undefined?
@@ -82,7 +88,7 @@ sub _lazy_parse($) {
         $parsed_lazily = 1;
     }
 }
- 
+
 
 #---------------------------------------------------------------------
 # Returns snippet htmls which can embedded without any side effects
@@ -91,21 +97,11 @@ sub _lazy_parse($) {
 sub snippet_html($) {
     my $self = shift;
     my $str = "";
-    my %colors = ();
 
     $self->_lazy_parse();
     
-    my $CSS = File::Spec->join($SHARED,"p6_style.css");
-    open CSS_FILE, $CSS
-        or die "Could not open $CSS: $OS_ERROR\n";
-    my $line;
-    while($line = <CSS_FILE>) {
-        if($line =~ /^\s*\.(\w+)\s*{\s*(.+?)\s*}/) {
-            $colors{$1} = $2;
-        }
-    }
-    close CSS_FILE;
-
+    my %colors = _read_css_file();
+    
     $str .= "<pre>";
 
     local *spit_snippet_html = sub {
@@ -131,35 +127,29 @@ sub snippet_html($) {
 sub simple_html($) {
     my $self = shift;
     my $str = "";
-    my %colors = ();
 
     $self->_lazy_parse();
 
-    my $CSS = File::Spec->join($SHARED,"p6_style.css");
-    open CSS_FILE, $CSS
-        or die "Could not open $CSS: $OS_ERROR\n";
-    my $line;
-    while($line = <CSS_FILE>) {
-        if($line =~ /^\s*\.(\w+)\s*{\s*color\s*:\s*(\w+)/) {
-            $colors{$1} = $2;
-        }
-    }
-    close CSS_FILE;
-
+    my %colors = _read_css_file();
+ 
     # slurp css inline it
-    my $css = qq{<link href="$CSS" rel="stylesheet" type="text/css">};
-    if(!$self->{clean_html}) {
-        $css = _slurp($CSS)
-            or die "Error while slurping file: $OS_ERROR\n";
+    my $css; 
+    if($self->{inline_resources}) {
+        $css = _slurp(_shared(FILE_CSS))
+            or croak "Error while slurping file: $OS_ERROR\n";
         $css = qq{<style type="text/css">\n$css\n</style>};
+    } else {
+        my $prefix = $self->{resource_url};
+        $css = qq{<link href="$prefix} . 
+            FILE_CSS . 
+            qq{" rel="stylesheet" type="text/css">};
     }
-
-    my $file = $self->{file};
+    my $page_title = $self->{page_title};
     my $timestamp = localtime;
     $str .= <<"HTML";
 <html>
 <head>
-    <title>$file</title>
+    <title>$page_title</title>
 <!--
      Generated by $PROGRAM_NAME at $timestamp
 -->
@@ -201,42 +191,39 @@ sub full_html($) {
     $self->_lazy_parse();
 
     # slurp libraries and javascript to inline them
-    my ($JQUERY_JS,$JS,$CSS) = (
-        File::Spec->join($SHARED,'jquery-1.2.6.pack.js'), 
-        File::Spec->join($SHARED,'p6_style.js'),
-        File::Spec->join($SHARED,'p6_style.css'));
-    my %colors = ();
-    my $line;
-    open CSS_FILE, $CSS
-        or die "Could not open $CSS: $OS_ERROR\n";
-    while($line = <CSS_FILE>) {
-        if($line =~ /^\s*\.(\w+)\s*{\s*color\s*:\s*(\w+)/) {
-            $colors{$1} = $2;
-        }
-    }
-    close CSS_FILE;
-
-    my $jquery_js = qq{<script type="text/javascript" src="$JQUERY_JS"></script>};
-    my $js = qq{<script type="text/javascript" src="$JS"></script>};
-    my $css = qq{<link href="$CSS" rel="stylesheet" type="text/css">};
-    if(!$self->{clean_html}) {
-        $jquery_js = _slurp($JQUERY_JS) 
-            or die "Error while slurping file: $OS_ERROR\n";    
-        $js = _slurp($JS) 
-            or die "Error while slurping file: $OS_ERROR\n";
-        $css = _slurp($CSS)
-            or die "Error while slurping file: $OS_ERROR\n";
-        $jquery_js = qq{<script type="text/javascript">\n$jquery_js\n</script>};
-        $js = qq{<script type="text/javascript">\n$js\n</script>};
-        $css = qq{<style type="text/css">\n$css\n</style>};
+    my %colors = _read_css_file();
+    my ($jquery_js,$js,$css);
+    if($self->{inline_resources}) {
+        my $contents;
+        $contents = _slurp(_shared(FILE_JQUERY)) 
+            or croak "Error while slurping file: $OS_ERROR\n";    
+        $jquery_js = qq{<script type="text/javascript">\n$contents\n</script>};
+        $contents = _slurp(_shared(FILE_JS)) 
+            or croak "Error while slurping file: $OS_ERROR\n";
+        $js = qq{<script type="text/javascript">\n$contents\n</script>};
+        $contents = _slurp(_shared(FILE_CSS))
+            or croak "Error while slurping file: $OS_ERROR\n";
+        $css = qq{<style type="text/css">\n$contents\n</style>};
+    } else {
+        my $prefix = $self->{resource_url};  
+        $jquery_js = 
+            qq{<script type="text/javascript" src="$prefix} . 
+            FILE_JQUERY . 
+            qq{"></script>};
+        $js = qq{<script type="text/javascript" src="$prefix} .
+            FILE_JS . 
+            qq{"></script>};
+        $css = qq{<link href="$prefix} .
+            FILE_CSS . 
+            qq{" rel="stylesheet" type="text/css">};
     }
 
-    my $file = $self->{file};
+    my $page_title = $self->{page_title};
     my $timestamp = localtime;
     $str .= <<"HTML";
 <html>
 <head>
-    <title>$file</title>
+    <title>$page_title</title>
 <!--
     Generated by $PROGRAM_NAME at $timestamp
 -->
@@ -282,20 +269,10 @@ HTML
 sub ansi_text($) {
     my $self = shift;
     my $str = "";
-    my %colors = ();
 
     $self->_lazy_parse();
 
-    my $ANSI = File::Spec->join($SHARED,"p6_style.ansi");
-    open ANSI_FILE, $ANSI
-        or die "Could not open $ANSI: $OS_ERROR\n";
-    my $line;
-    while($line = <ANSI_FILE>) {
-        if($line =~ /^(\w+)=(.+)$/) {
-            $colors{$1} = $2;
-        }
-    }
-    close ANSI_FILE;
+    my %colors = _read_ansi_file();
 
     local *spit_ansi_text = sub {
         my ($i, $buffer, $rule, $tree) = @ARG;
@@ -319,23 +296,11 @@ sub ansi_text($) {
 #---------------------------------------------------------------
 sub parse_trees($) {
     my $self = shift;
-    my $str = "";
-    my %colors = ();
 
     $self->_lazy_parse();
 
-    my $ANSI = File::Spec->join($SHARED,"p6_style.ansi");
-    open ANSI_FILE, $ANSI
-        or die "Could not open $ANSI: $OS_ERROR\n";
-    my $line;
-    while($line = <ANSI_FILE>) {
-        if($line =~ /^(\w+)=(.+)$/) {
-            $colors{$1} = $2;
-        }
-    }
-    close ANSI_FILE;
-
-    my @parse_trees = ();
+    my %colors = _read_ansi_file();
+    my @parse_trees = (); 
     local *spit_parse_tree = sub {
         push @parse_trees, @ARG;
     };
@@ -345,6 +310,47 @@ sub parse_trees($) {
     @parse_trees;
 }
 
+#--------------------------------------------------------------------
+# Reads the css file and return a hash of colors 
+#-------------------------------------------------------------------- 
+sub _read_css_file() {
+
+    my %colors = ();
+    my $filename = _shared(FILE_CSS);
+    open FILE, $filename
+        or croak "Could not open $filename: $OS_ERROR\n";
+    my $line;
+    while($line = <FILE>) {
+        if($line =~ /^\s*\.(\w+)\s*{\s*(.+?)\s*}/) {
+            $colors{$1} = $2;
+        }
+    }
+    close FILE;
+
+    %colors;
+}
+
+#--------------------------------------------------------------
+# Reads an ANSI rule-name=color property file and stores
+# the color values in a hash of rule-name,color
+#--------------------------------------------------------------
+sub _read_ansi_file {
+    my %colors = ();
+    my $filename = _shared(FILE_ANSI);
+    open FILE, $filename
+        or croak "Could not open $filename: $OS_ERROR\n";
+    my $line;
+    while($line = <FILE>) {
+        if($line =~ /^(\w+)=(.+)$/) {
+            $colors{$1} = $2;
+        }
+    }
+    close FILE;
+
+    %colors;
+}
+
+
 #---------------------------------------------------------------
 #    Helper private method that traverses STD.pm's parse 
 # tree array. It needs a callback process_buffer and a 
@@ -454,6 +460,14 @@ sub _escape_html($) {
     return $str;
 }
 
+#-----------------------------------------------------
+# convert to shared package real resource path
+#-----------------------------------------------------
+sub _shared($) {
+    my $path = shift;
+    return File::Spec->join($SHARED, $path);
+}
+
 #-----------------------------------------------------
 # Load file into a scalar without File::Slurp
 # Thanks ofcourse to this post
@@ -535,19 +549,23 @@ This is where you should provide the Perl 6 code.
 
 =item rule
 
-parse rule name for STD.pm to parse against (default: B<comp_unit>)
+parse rule name for STD.pm to parse against (default: comp_unit)
 
-=item clean_html
+=item inline_resources
 
-Flag to enable/disable CSS/JavaScript HTML inlining. (default: 1)
+Flag to enable/disable CSS/JavaScript HTML inlining. (default: 0 (Disabled))
 
-=item file
+=item resource_url
 
-file name string in HTML modes (default: a warning message)
+HTML resource url that will be appended when resource inlining is disabled.
+
+=item page_title
+
+HTML page title for C<simple_html> and <full_html> (default: '')
 
 =item utf8_decode
 
-Flag to enable/disable utf8 decoding. (default: 1)
+Flag to enable/disable utf8 decoding. (default: 1 (Enabled))
 
 =back
 
@@ -558,14 +576,14 @@ No CSS or JavaScript is inside.
 
 =item simple_html
 
-Returns the Perl 6 highlighted HTML string. The HTML is the same as 
-C<full_html> but lacks a JavaScript Parse Tree Viewer. 
+Returns the Perl 6 highlighted HTML string. The HTML code is the same 
+as C<full_html> but lacks a JavaScript Parse Tree Viewer. 
 
 =item full_html
 
 Returns the Perl 6 highlighted HTML string. The HTML consists of a 
 JavaScript Parse Tree Viewer along with CSS-styling. 
-It can inlined if C<clean_html> option is 0. 
+It can inlined if C<inline_resources> option is 1. 
 
 =item ansi_text
 
